@@ -1,5 +1,5 @@
 
-from .clientBase import MqClientExceptionClass, MqClientProcessLoopTimeoutExceptionClass
+from .clientBase import MqClientExceptionClass, MqClientProcessLoopTimeoutExceptionClass, MqClientThreadHealthCheckExceptionClass
 from .main import createObjectStoreInstance
 
 from ._version import get_versions
